Skip to contents

Backquote text by combining with backticks (“).

Usage

bckQuote(x)

Arguments

x

an R object, to be coerced to a character vector.

Value

A character vector of the same length as x (after any coercion).

See also

Examples

bckQuote("example")
#> [1] "`example`"
bckQuote(c("one", "two", "three"))
#> [1] "`one`"   "`two`"   "`three`"
bckQuote(123)
#> [1] "`123`"