is.boolean checks if an object is a single logical value
(TRUE or FALSE).
is.string checks if an object is a single (non-NA) character string.
nzstring checks if an object is a single (non-NA) non-empty character
string.
is.boolean checks if an object is a single logical value
(TRUE or FALSE).
is.string checks if an object is a single (non-NA) character string.
nzstring checks if an object is a single (non-NA) non-empty character
string.